@@ -1,17 +1,15 @@
 from lazyTest.file import IniFileOperation,Csv_File_Operation
-from lazyTest.log import GetLogger
 from lazyTest.utils import Sleep, readElementSource,writeElementKey, ClearTestResult, createData,cls_Sleep
 from lazyTest.case import TestCase
 from lazyTest.base import  browser_Config
 from lazyTest.page import Page
 
-__version__ = '1.0.9'
+__version__ = '1.1.2'
 
 
 __description__ = ""
 
 __all__ = [
-    "GetLogger",
     "Sleep",
     "Page",
     "readElementSource",
