@@ -7,7 +7,6 @@
 # ---------------------------------------
 import time
 
-import pytest
 from selenium import webdriver
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.webelement import WebElement
@@ -197,9 +196,22 @@ class browser_Config:
         value： 用于获取元素的value属性
         """
         ele = self.locate_element(selector)
-
         return ele.get_attribute(value)
 
+    def addAttribute(self, selector: str, attributeName : str, value : str):
+        '''
+        封装向页面标签添加新属性的方法
+        '''
+        ele = self.locate_element(selector)
+        self.base_driver.execute_script("arguments[0].%s=arguments[1]" % attributeName, ele, value)
+
+    def setAttribute(self, selector: str, attributeName: str, value: str):
+        '''
+        封装设置页面对象的属性值的方法
+        '''
+        ele = self.locate_element(selector)
+        self.base_driver.execute_script("arguments[0].setAttribute(arguments[1],arguments[2])", ele, attributeName, value)
+
     def switch_frame_1(self, frame_name: str) -> None:
         """根据框架名称切换"""
         self.base_driver.switch_to.frame(frame_name)
