@@ -96,28 +96,20 @@ sys.path.append(os.path.dirname(os.path.dirname(__file__)))
 from lazyTest import *
 
 globals()["driver"] = None
-globals()["filepath"] = None
-
-
-def getPorjectPath():
-    '''
-    获取项目路径
-    '''
-    return os.path.dirname(os.path.dirname(__file__))
 
 
 def pytest_addoption(parser):
     # 添加参数到pytest.ini
     parser.addini('Terminal', help='访问浏览器参数')
-    parser.addini('URL',  help='添加 url 访问地址参数')
+    parser.addini('URL', help='添加 url 访问地址参数')
     parser.addini('filepath', help='添加 截图路径')
+    parser.addini('logpath', help='添加 日志路径')
 
 
 @pytest.fixture(scope='session')
 def getdriver(pytestconfig):
     Terminal = pytestconfig.getini("Terminal")
     URL = pytestconfig.getini("URL")
-    globals()["filepath"] = pytestconfig.getini('filepath')
     driver = browser_Config(Terminal, URL)
     globals()["driver"] = driver.base_driver
     yield driver
@@ -133,35 +125,54 @@ def flush_browser(getdriver):
 
 # 用例出现异常或失败时截图
 @pytest.hookimpl(hookwrapper=True)
-def pytest_runtest_makereport():
-<<<<<<< HEAD
-=======
-    picture_time = time.strftime("%Y-%m-%d-%H-%M-%S", time.localtime(time.time()))
-    filename = getPorjectPath() + globals()["filepath"] + picture_time + ".png"
->>>>>>> 14ead3f648d6acda6dfa6a24bc2a4be5529989d7
+def pytest_runtest_makereport(item):
+    config = item.config
     outcome = yield
     report = outcome.get_result()
     if report.when == 'call':
         xfail = hasattr(report, 'wasxfail')
-<<<<<<< HEAD
         if report.failed and not xfail:
+            project = str(config.rootpath)
+            filepath = config.getini("filepath")
             picture_time = time.strftime("%Y-%m-%d-%H-%M-%S", time.localtime(time.time()))
-            filename = getPorjectPath() + globals()["filepath"] + picture_time + ".png"
-=======
-        if (report.skipped and xfail) or (report.failed and not xfail):
->>>>>>> 14ead3f648d6acda6dfa6a24bc2a4be5529989d7
+            filename = project + filepath + picture_time + ".png"
             globals()["driver"].save_screenshot(filename)
             with open(filename, "rb") as f:
                 file = f.read()
                 allure.attach(file, "失败截图", allure.attachment_type.PNG)
 
+
+@pytest.hookimpl(hookwrapper=True, tryfirst=True)
+def pytest_runtest_setup(item):
+    config = item.config
+    project = str(config.rootpath)
+    logpath = config.getini("logpath")
+    logging_plugin = config.pluginmanager.get_plugin("logging-plugin")
+    logging_plugin.set_log_path(project + logpath)
+    yield
+
     """
 
     pytest = """
 [pytest]
-Terminal = Chrome
-URL = https://www.baidu.com
+
+
+log_cli = true
+log_cli_level = INFO
+log_format = %(levelname)s %(asctime)s [%(filename)s:%(lineno)-s] %(message)s
+log_date_format = %Y-%M-%D %H:%M:%S
+
+
+
+log_file_level = INFO
+log_file_format = %(levelname)s %(asctime)s [%(filename)s:%(lineno)-s] %(message)s
+log_file_date_format = %Y-%M-%D %H:%M:%S
+
+
+Terminal = ChromeOptions
+URL = 
 filepath = /result/screenshot/
+logpath = /result/log/log.log
     """
 
     main = """
@@ -170,11 +181,7 @@ import sys
 import time
 
 sys.path.append(os.path.dirname(os.path.dirname(__file__)))
-<<<<<<< HEAD
 from lazyTest import ClearTestResult
-=======
-from lazy import ClearTestResult
->>>>>>> 14ead3f648d6acda6dfa6a24bc2a4be5529989d7
 
 
 def getPorjectPath():
@@ -194,25 +201,24 @@ def clearLogAndReport():
 
 def runlastFailed():
     print("启动失败用例重跑")
-    cmd = "pytest -s --lf " + getPorjectPath() + "/case/  --alluredir " + getPorjectPath() + "/result/report"
+    cmd = "pytest -s --lf {}/case --alluredir {}/result/report".format(getPorjectPath(), getPorjectPath())
     print(os.system(cmd))
 
 
 def startReport():
     print("-------------启动测试报告--------------")
-    startReport = "allure serve " + getPorjectPath() + "/result/report"
-    print(os.system(startReport))
+    cmd = "allure serve {}/result/report".format(getPorjectPath())
+    print(os.system(cmd))
 
 
 def startCase(cases):
     print("------------开始执行测试------------")
-    cmd = "pytest -s " + getPorjectPath() + "/case/" + cases + " --alluredir " + getPorjectPath() + "/result/report"
+    cmd = "pytest -s {}/case/{} --alluredir {}/result/report".format(getPorjectPath(), cases, getPorjectPath())
     print(os.system(cmd))
 
 
 def run(cases=" "):
-    '''运行case中所有用例'''
-    # clearLogAndReport()
+    clearLogAndReport()
     startCase(cases)
     s = input("请选择要启用的服务:1:启动失败用例重跑;\t2：启动测试报告;")
     if s == "1":
@@ -227,7 +233,7 @@ run()
 
     create_folder(project_name)  # 创建项目目录
     # 创建目录结构
-    create_folder(os.path.join(project_name, "page"))
+    create_folder(os.path.join(project_name, "pages"))
     create_folder(os.path.join(project_name, "service"))
     create_folder(os.path.join(project_name, "case"))
     create_folder(os.path.join(project_name, "main"))
