@@ -33,19 +33,11 @@ class YamlOperation(FileOperation):
     def writeFileToDict(realFile, data):
         """写入yaml文件"""
         with open(realFile, "w", encoding="utf-8") as f:
-            yaml.dump(data, f, Dumper=yaml.RoundTripDumper)
+            yaml.round_trip_dump(data, f, Dumper=yaml.RoundTripDumper, default_flow_style=False)
 
 
 class IniFileOperation(FileOperation):
 
-    @staticmethod
-    def read_Ini():
-        """读取ini配置文件"""
-        Ini_Path = sys.path[-1] + r"\resources\conf\config.ini"
-        config = configparser.ConfigParser()
-        config.read(Ini_Path)
-        return config
-
     def readFileToDict(self):
         """读取ini文件"""
         config = configparser.ConfigParser()
@@ -61,11 +53,23 @@ class JsonFileOperation(FileOperation):
             json_data = json.load(fp)
         return json_data
 
+    @staticmethod
+    def writeFileToDict(realFile, data):
+        """将字典格式数据写入到Json文件"""
+        with open(realFile, 'w', encoding='utf8')as fp:
+            json.dump(data, fp, ensure_ascii=False)
+
 
 class Csv_File_Operation(FileOperation):
 
     def readFileToList(self):
-        """读取CSV文件"""
+        """读取CSV文件,参数化使用"""
         with open(self.filePath, 'r', encoding='utf8')as fp:
             data_list = [i for i in csv.reader(fp)]
+        if len(data_list[0]) == 1:
+            data_list.pop(0)  # 去首行
+            return [i[0] for i in data_list]
+        else:
+            data_list.pop(0)  # 去首行
+
         return data_list
